package org.bitbucket.bradleysmithllc.etlunit.feature.informatica;

import org.bitbucket.bradleysmithllc.etlunit.Log;
import org.bitbucket.bradleysmithllc.etlunit.NullClassDirector;
import org.bitbucket.bradleysmithllc.etlunit.context.VariableContext;
import org.bitbucket.bradleysmithllc.etlunit.feature.RuntimeOption;
import org.bitbucket.bradleysmithllc.etlunit.feature.informatica.util.InformaticaRepositoryClient;
import org.bitbucket.bradleysmithllc.etlunit.feature.informatica.util.InformaticaRepositoryClientImpl;
import org.bitbucket.bradleysmithllc.etlunit.parser.ETLTestValueObject;

import javax.inject.Inject;
import javax.inject.Named;
import java.util.Map;

public class InformaticaDirector extends NullClassDirector
{
	private Log applicationLog;

	private boolean loadWorkflows = true;
	private boolean cleanRepository = false;

	private VariableContext variableContext;
	private InformaticaConfiguration informaticaConfiguration;
	private InformaticaFeatureModule informaticaFeatureModule;

	@Inject
	public void receiveInformaticaFeatureModule(InformaticaFeatureModule icon)
	{
		informaticaFeatureModule = icon;
	}

	@Inject
	public void receiveInformaticaConfiguration(InformaticaConfiguration icon)
	{
		informaticaConfiguration = icon;
	}

	@Inject
	public void setLogger(VariableContext vcon)
	{
		variableContext = vcon;
	}

	@Inject
	public void setLogger(@Named("applicationLog") Log logger)
	{
		this.applicationLog = logger;
	}

	@Inject
	public void setCleanRepository(@Named("informatica.cleanRepository") RuntimeOption option)
	{
		cleanRepository = option.isEnabled();

		applicationLog.info(cleanRepository ? "Cleaning repository." : "Leaving turds in repository.");
	}

	@Inject
	public void setLoadWorkflows(@Named("informatica.loadWorkflows") RuntimeOption option)
	{
		loadWorkflows = option.isEnabled();

		applicationLog.info(loadWorkflows ? "Loading workflows from project" : "Using workflows resident in informatica repository");
	}

	@Override
	public void endBroadcast()
	{
		InformaticaRepositoryClientImpl.resetClientCount();

		if (cleanRepository)
		{
			ETLTestValueObject container = InformaticaExecutor.getInformaticaContainer(variableContext, false);

			if (container != null)
			{
				Map<String, ETLTestValueObject> map = container.getValueAsMap();

				for (Map.Entry<String, ETLTestValueObject> entry : map.entrySet())
				{
					applicationLog.info("Purging temporary informatica folders for domain: " + entry.getKey());

					InformaticaDomain domain = informaticaConfiguration.getDomain(entry.getKey());

					Map<String, ETLTestValueObject> mapRepo = entry.getValue().getValueAsMap();

					for (Map.Entry<String, ETLTestValueObject> entryRepo : mapRepo.entrySet())
					{
						applicationLog.info("Purging temporary informatica folders for repository: " + entryRepo.getKey());

						InformaticaRepository repository = domain.getRepository(entryRepo.getKey());

						InformaticaRepositoryClient client = null;
						try
						{
							client = repository.getInformaticaRepositoryClient();

							if (loadWorkflows)
							{
								applicationLog.info("Purging temporary informatica folders.");

								Map<String, ETLTestValueObject> fMap = entryRepo.getValue().query(InformaticaExecutor.INFORMATICA_CREATED_FOLDERS).getValueAsMap();

								for (Map.Entry<String, ETLTestValueObject> folderEntry : fMap.entrySet())
								{
									applicationLog.info("Purging temporary informatica folder: " + folderEntry.getKey());

									client.deleteFolder(folderEntry.getKey());
								}
							}
							else
							{
								applicationLog.info("Nothing to clean up for repository " + repository.getQualifiedName() + " since load workflows is turned off.");
							}

							Map<String, ETLTestValueObject> fMap = entryRepo.getValue().query(InformaticaExecutor.INFORMATICA_CREATED_CONNECTIONS).getValueAsMap();

							for (Map.Entry<String, ETLTestValueObject> connectionEntry : fMap.entrySet())
							{
								applicationLog.info("Purging temporary informatica folder: " + connectionEntry.getKey());

								client.deleteFolder(connectionEntry.getKey());
							}
						}
						catch (Exception testExecutionError)
						{
							throw new RuntimeException(testExecutionError);
						}
					}
				}
			}

			applicationLog.info("Purging connection objects.");

		}
		else
		{
			applicationLog.info("Not cleaning repository.");
		}
	}
}