package org.bitbucket.bradleysmithllc.etlunit.feature.informatica;

import org.bitbucket.bradleysmithllc.etlunit.RuntimeSupport;
import org.bitbucket.bradleysmithllc.etlunit.io.FileBuilder;

import javax.inject.Inject;
import java.io.File;

public class InformaticaRuntimeSupportImpl implements InformaticaRuntimeSupport
{
	private RuntimeSupport runtimeSupport;

	@Inject
	public void setRuntimeSupport(RuntimeSupport runtimeSupport)
	{
		this.runtimeSupport = runtimeSupport;
	}

	public File getInformaticaSourceDirectory()
	{
		return runtimeSupport.getFeatureSourceDirectory("informatica");
	}

	public File getInformaticaSourceDirectory(String folder)
	{
		return new FileBuilder(getInformaticaSourceDirectory()).subdir(folder).mkdirs().file();
	}

	public File getInformaticaWorkflowParameterDirectory(String folder)
	{
		return new FileBuilder(getInformaticaSourceDirectory(folder)).subdir("ParameterFiles").mkdirs().file();
	}

	public File getInformaticaWorkflow(String folder, String workflowName)
	{
		return new FileBuilder(getInformaticaSourceDirectory(folder)).name(workflowName + ".xml").file();
	}

	public File getInformaticaWorkflowParameterTemplate(String folder, String workflowName)
	{
		return new FileBuilder(getInformaticaWorkflowParameterDirectory(folder)).name(workflowName + ".PRM").file();
	}

	public File getSrcFilesRemote(InformaticaDomain domain)
	{
		File localRoot = domain.getLocalizedWorkingRoot();
		File srcFiles = new FileBuilder(localRoot).subdir("SrcFiles").file();
		srcFiles.mkdirs();
		return srcFiles;
	}

	public File getLkpFilesRemote(InformaticaDomain domain)
	{
		File localRoot = domain.getLocalizedWorkingRoot();

		File lkpFiles = new FileBuilder(localRoot).subdir("LkpFiles").file();
		lkpFiles.mkdirs();

		return lkpFiles;
	}

	public File getTgtFilesRemote(InformaticaDomain domain)
	{
		File localRoot = domain.getLocalizedWorkingRoot();

		File tgtFiles = new FileBuilder(localRoot).subdir("TgtFiles").file();
		tgtFiles.mkdirs();

		return tgtFiles;
	}

	public File getBadFilesRemote(InformaticaDomain domain)
	{
		File localRoot = domain.getLocalizedWorkingRoot();

		File badFiles = new FileBuilder(localRoot).subdir("BadFiles").file();
		badFiles.mkdirs();

		return badFiles;
	}

	public File getLogFilesRemote(InformaticaDomain domain)
	{
		File localRoot = domain.getLocalizedWorkingRoot();

		File logFiles = new FileBuilder(localRoot).subdir("SessionLogs").file();
		logFiles.mkdirs();

		return logFiles;
	}

	public File getParmFilesRemote(InformaticaDomain domain)
	{
		File localRoot = domain.getLocalizedWorkingRoot();

		File parmlib = new File(localRoot, "ParameterFiles");
		parmlib.mkdirs();

		return parmlib;
	}
}